@@ -1,4 +1,5 @@
 import os
+import platform
 import time
 import numpy as np
 import cv2
@@ -9,6 +10,10 @@ t = Terminal(debug=True)
 
 class CommonGUI():
     def __init__(self, project_name=""):
+        if platform == "darwin":
+            # OS X
+            print("Sorry, the Mac m1,m2,m3,mx... is totally garbage in my eyes. \nIt even does not support VirtualBox and docker auto-start.\nTry to use Linux, for example, Ubuntu, my friend!")
+            exit()
         try:
             import pyautogui as pyautogui
         except Exception:
@@ -67,7 +72,7 @@ To use this module, you have to install pyautogui:
         """
         delay for milliseconds
         """
-        time.sleep(milliseconds/1000)
+        time.sleep(milliseconds / 1000)
 
     def find_text(self, target_text, from_image=None):
         """
@@ -77,7 +82,7 @@ To use this module, you have to install pyautogui:
         """
 
         try:
-            #from PIL import Image
+            # from PIL import Image
             import pyscreenshot as ImageGrab
         except ImportError:
             error = """
@@ -109,8 +114,8 @@ To use this module, you have to install tesseract:
                 for attribute in list_:
                     value = result[attribute][t_index]
                     my_dict.update({attribute: value})
-                x = my_dict['left'] + my_dict['width']/2
-                y = my_dict['top'] + my_dict['height']/2
+                x = my_dict['left'] + my_dict['width'] / 2
+                y = my_dict['top'] + my_dict['height'] / 2
                 return_list.append((x, y))
         if (len(return_list) != 0):
             return return_list
@@ -131,7 +136,7 @@ class GUI(CommonGUI):
     def __click(self, x, y, game=False):
         self.pyautogui.click(x, y, interval=self.__time_takes_for_one_click)
         if game == True:
-            self.pyautogui.click(x, y+1, interval=self.__time_takes_for_one_click)
+            self.pyautogui.click(x, y + 1, interval=self.__time_takes_for_one_click)
 
     def __get_tuple(self, element_name, confidence=0.9):
         self._make_sure_img_dict_exists()
@@ -227,7 +232,41 @@ To use this module, you have to install pyautogui:
     def mouse_click(self, x=None, y=None, button='left', interval=0.5, game=False):
         self.pyautogui.click(x=x, y=y, button=button, interval=interval)
         if game == True:
-            self.pyautogui.click(x=x+1, y=y+1, button=button, interval=interval)
+            self.pyautogui.click(x=x + 1, y=y + 1, button=button, interval=interval)
+
+    def write(self, text: str):
+        self.pyautogui.write(text)
+
+    def press(self, key: str):
+        """
+        self.pyautogui.KEYBOARD_KEYS
+
+        or
+
+        ['\t', '\n', '\r', ' ', '!', '"', '#', '$', '%', '&', "'", '(',
+         ')', '*', '+', ',', '-', '.', '/', '0', '1', '2', '3', '4', '5', '6', '7',
+         '8', '9', ':', ';', '<', '=', '>', '?', '@', '[', '\\', ']', '^', '_', '`',
+         'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o',
+         'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z', '{', '|', '}', '~',
+         'accept', 'add', 'alt', 'altleft', 'altright', 'apps', 'backspace',
+         'browserback', 'browserfavorites', 'browserforward', 'browserhome',
+         'browserrefresh', 'browsersearch', 'browserstop', 'capslock', 'clear',
+         'convert', 'ctrl', 'ctrlleft', 'ctrlright', 'decimal', 'del', 'delete',
+         'divide', 'down', 'end', 'enter', 'esc', 'escape', 'execute', 'f1', 'f10',
+         'f11', 'f12', 'f13', 'f14', 'f15', 'f16', 'f17', 'f18', 'f19', 'f2', 'f20',
+         'f21', 'f22', 'f23', 'f24', 'f3', 'f4', 'f5', 'f6', 'f7', 'f8', 'f9',
+         'final', 'fn', 'hanguel', 'hangul', 'hanja', 'help', 'home', 'insert', 'junja',
+         'kana', 'kanji', 'launchapp1', 'launchapp2', 'launchmail',
+         'launchmediaselect', 'left', 'modechange', 'multiply', 'nexttrack',
+         'nonconvert', 'num0', 'num1', 'num2', 'num3', 'num4', 'num5', 'num6',
+         'num7', 'num8', 'num9', 'numlock', 'pagedown', 'pageup', 'pause', 'pgdn',
+         'pgup', 'playpause', 'prevtrack', 'print', 'printscreen', 'prntscrn',
+         'prtsc', 'prtscr', 'return', 'right', 'scrolllock', 'select', 'separator',
+         'shift', 'shiftleft', 'shiftright', 'sleep', 'space', 'stop', 'subtract', 'tab',
+         'up', 'volumedown', 'volumemute', 'volumeup', 'win', 'winleft', 'winright', 'yen',
+         'command', 'option', 'optionleft', 'optionright']
+        """
+        self.pyautogui.press(key)
 
 
 class AndroidGUI(CommonGUI):
@@ -247,13 +286,14 @@ To use this module, you have to install scrcpy
 To use this module, you have to install adb:
     sudo apt install android-tools-adb
 """
-        
+
         try:
             from uiautomator import device as d
             self.d = d
         except Exception as e:
             print(e)
-            print("I suggest you to use uiautomator to handle your android phone. You can install it by: \nsudo pip3 install uiautomator")
+            print(
+                "I suggest you to use uiautomator to handle your android phone. You can install it by: \nsudo pip3 install uiautomator")
 
         info_of_android = t.run_command("adb shell dumpsys display")
         for line in info_of_android.split("\n"):
@@ -300,7 +340,7 @@ To use this module, you have to install adb:
         result = []
         w, h = template.shape[::-1]
         for pt in zip(*loc[::-1]):
-            x, y = (pt[0] + w/2), (pt[1] + h/2)
+            x, y = (pt[0] + w / 2), (pt[1] + h / 2)
             result.append({"x": x, "y": y})
             if visual:
                 cv2.rectangle(from_image, pt, (pt[0] + w, pt[1] + h), (0, 0, 255), 2)
@@ -335,17 +375,17 @@ To use this module, you have to install adb:
         x = point["x"]
         y = point["y"]
         if landscape:
-            x = int(x/self.__screen_width*self.__android_height)
-            y = int(y/self.__screen_height*self.__android_width)
+            x = int(x / self.__screen_width * self.__android_height)
+            y = int(y / self.__screen_height * self.__android_width)
         else:
-            x = int(x/self.__screen_width*self.__android_width)
-            y = int(y/self.__screen_height*self.__android_height)
+            x = int(x / self.__screen_width * self.__android_width)
+            y = int(y / self.__screen_height * self.__android_height)
         t.run(f"adb shell input tap {x} {y}")
 
 
 if __name__ == "__main__":
     androidGUI = AndroidGUI("pixel")
-    while(True):
+    while (True):
         data = androidGUI.capture_screen()
         cv2.imshow('frame', data)
         if cv2.waitKey(1) & 0xFF == ord('q'):
